# utils

Implements simple extensions to the core python libraries.

To install:

```
pip install utils-nuuuwan
```

To install development version (which might have more features, but also be
less stable):

```
pip install -i https://test.pypi.org/simple/ utils-nuuuwan
```

# Release History

## 1.0.1 (DO NOT USE - WILL BREAK utils.cache)

* Added get_unixtime and parse_time to *timex*.
* Fixed big in timeout logic in *cache*

## 1.0.2

* Fixed breaking bug in *cache* timeout logic.
